ams.opt.Constraint
==================

.. currentmodule:: ams.opt

.. autoclass:: Constraint

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~Constraint.evaluate
       
       
          ~Constraint.parse
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~Constraint.class_name
      ~Constraint.e
      ~Constraint.n
      ~Constraint.shape
      ~Constraint.size
      ~Constraint.v
   
   